import inspect

from shutterstock import resources


class ConfiguredAPI:
    pass


def configure_api(api):
    res = ConfiguredAPI()

    for name, val in resources.__dict__.items():
        if inspect.isclass(val) and issubclass(val, resources.Resource):
            setattr(res, name, type(name, (val,), {'API': api}))

    return res


def configure(token):
    from shutterstock.api import ShutterstockAPI
    return configure_api(ShutterstockAPI(token))



import json
import requests


class ShutterstockAPI:
    def __init__(self, token):
        self.token = token

    def get(self, endpoint, **params):
        headers = {
            'Content-Type': 'application/xml',
            'Authorization': 'Bearer {token}'.format(
                token=self.token
            )
        }

        endpoint = endpoint.format(**params)

        response = requests.get(
            'https://api.shutterstock.com/v2{endpoint}'.format(
                endpoint=endpoint
            ),
            params=params,
            headers=headers
        )

        return json.loads(response.content)




class Resource:
    API = None
    LIST = None
    GET = None
    CREATE = None
    UPDATE = None
    DELETE = None

    @classmethod
    def all(cls, **params):
        return cls.API.get(cls.LIST, **params)

    @classmethod
    def get(cls, **params):
        return cls.API.get(cls.GET, **params)


class Image(Resource):
    LIST = '/images'
    GET = '/images/{id}'


class ImageCollection(Resource):
    LIST = '/images/collections'
    GET = '/images/collections/{id}'


class ImageLicense(Resource):
    LIST = '/images/licenses'



from distutils.core import setup
from pkgutil import walk_packages

import shutterstock


def find_packages(path, prefix=""):
    yield prefix
    prefix = prefix + "."
    for _, name, ispkg in walk_packages(path, prefix):
        if ispkg:
            yield name


setup(
  name='shutterstock',
  packages=list(find_packages(shutterstock.__path__, shutterstock.__name__)),
  version='0.1.0',
  description='Pyhton Shutterstock API Client',
  author='Matt Roberts',
  author_email='contact@maleero.com',
  url='https://github.com/malero/python-shutterstock-api',
  download_url='https://github.com/malero/python-shutterstock-api/archive/v0.1.0.tar.gz',
  keywords=['shutterstock', ],
  classifiers=[],
  install_requires=['requests==2.19.1', ],
)
